.TH VG l "January 1990"
.SH NAME
.I VG
(VolksGrapher) 3.06 \- a FORTRAN callable graphing package
.SH SYNOPSIS (Linux)
fort77 -O3 -o example example.f -lvg -lvgx11 -lX11 -lm (for X-windows)

fort77 -O3 -o example example.f -lvg -lvgtek -lm (for Tektronix output)

fort77 -O3 -o example example.f -lvg -lvgbat -lm (for batch operation)

.SH SYNOPSIS (SUN3)
f77 -o example example.f -lvg -lvgsun -lcgi77 -lcgi -lsuntool -lsunwindow -lpixrect /usr/lib/f68881.il -lm (for Sun Windows)

f77 -o example example.f -Bstatic -lvg -lvgtek /usr/lib/f68881.il -lm (for Tektronix output)

f77 -o example example.f -Bstatic -lvg -lvgbat /usr/lib/f68881.il -lm (for batch operation)

.SH SYNOPSIS (SUN4)
f77 -o example example.f -Bstatic -lvg -lvgsun -lcgi77 -lcgi -lsuntool -lsunwindow -lpixrect /usr/lib/f68881/libm.il -lm (for Sun Windows)

f77 -o example example.f -Bstatic -lvg -lvgtek /usr/lib/f68881/libm.il -lm (for Tektronix output)

f77 -o example example.f -Bstatic -lvg -lvgbat /usr/lib/f68881/libm.il -lm (for batch operation)

.SH DESCRIPTION
.IR VG (l)
is a FORTRAN callable two dimensional graphing package.  It runs on IBM pcs,
Sun Workstations, and some mainframes producing output to the screen,
Epson compatible printers, PostScript and QMS laser printers,
HPGL plotters and Tektronix 4010 terminals. The Sun version of 
.I VG
can produce screen output in a SunWindows graphics window or
on a Tektronix emulation window such as 
.I tektool
or
.I X Windows,
.I xterm.
.LP
Internal routines begin with 
.I VGxxx. 
Don't use such names in your program!  Common errors in using 
.I VG 
are: (1) calling a routine with the wrong number of arguments, 
(2) calling a routine with arguments of the wrong type, 
e.g. using 4 (integer) when 4.0 (real) is required. Numeric 
parameter names that begin with 
.I I 
through 
.I N
are integers; all other numbers are real, (3) forgetting to call 
.I NEWPAG
between pages of graphs.
.LP
.SH BASIC CALLS
.LP
Example:

.RS
.nf
.ta .65i +.3i
	DIMENSION X(100), Y1(100), Y2(100)
	DO 10 I=1,100
		X(I)=0.06*I
		Y1(I)=SIN(X(I))
		Y2(I)=COS(X(I))
10	CONTINUE
20	CONTINUE
		CALL CURV(100, X, Y1)
		CALL CURV(100, X, Y2)
		CALL VG
	IF(LOOPIN() .EQ. 1) GOTO 20
	END
.fi
.RE

Produces a full screen plot. Two curves will appear on the same graph, with 
different lines and symbols, and with axes and axis numbers.  After plotting
the graph the program will pause leaving you in the interactive mode
awaiting user input.  For example, to produce a PostScript file 
of the screen, hit 
.I 'p'; 
you will be asked for a file name. To leave the interactive mode and
continue with the next part of your program, press the
.I '<enter>'.
There may not 
be more than six graphs on each page.
.LP
Every screenful or plot page is generated by a program block of the form

.RS
.nf
XX	CONTINUE
		.
		.
	IF(LOOPIN() .EQ. 1) GOTO XX
.fi
.RE

.I VG
has interactive capabilities (see "Interactive" section). If you use them 
.I LOOPIN 
returns 1, jumping to label 
.I XX 
(perhaps several times). Don't put 
heavy computation inside this loop unless it is needed. When you type 
.I '<enter>', LOOPIN 
returns 0, exiting the loop. 
.LP
You can control graphing symbols, line types, colors, position on screen, 
etc., by optional calls.  

Example: Plot two data sets on left and right half of screen.

.RS
.nf
	DIMENSION X(100), Y1(100), Y2(100)
	... same as above ...
20	CONTINUE 
		CALL PLAC(1.0, 0.0, 0.0, 0.5)
C		(TOP, BOTTOM, LEFT, RIGHT) 
C		[Screen is unit square, origin is bottom left.]
		CALL CURV(100, X, Y1)
		CALL VG
		CALL PLAC(1.0, 0.0, 0.5, 1.0)
		CALL CURV(100, X, Y2)
		CALL VG
	IF(LOOPIN() .EQ. 1) GOTO 20
	END
.fi
.RE

Separate screens or separate plot pages require separate loops, with a call
to 
.I NEWPAG 
between them.

Example: Screen 1 with full size plot.  Screen 2 with plot in middle third.

.RS
.nf
	DIMENSION X(100), Y1(100), Y2(100)
	... same as before ...
20	CONTINUE
		CALL CURV(100, X, Y1)
		CALL VG
	IF(LOOPIN() .EQ. 1) GOTO 20
	CALL NEWPAG
30	CONTINUE 
		CALL PLAC(0.66, 0.33, 0.33, 0.66)
		CALL CURV(100, X, Y2)
		CALL VG
	IF(LOOPIN() .EQ. 1) GOTO 30
	END
.fi
.RE

.SH USING OPTIONAL CALLS

Options affect the next curve drawn, the current graph, or the current
page.  Options for the current graph must appear before any calls to
.I CURV 
on that graph.  The 
general form for using options is: 

.RS
.nf
        <optional calls affecting the entire page, SETDV, SETXIT, SCALUP>
XX	<optional calls affecting the first graph,
		PLAC, AXCODE, LINLOG, SIDTEX, SETLIM, etc...>
		<optional calls affecting the first curve,
		HOWPLT, RIGHT, LEGND>
		CALL CURV(<first data set>)

		<optional calls affecting the next curve>
		CALL CURV(<next data set>)
		...
		CALL CURV(<last data set>)
		CALL VG

	<optional calls affecting the second graph>
		...
		CALL VG

		(more graphs)
	IF(LOOPIN() .EQ. 1) GOTO XX

	<CALL NEWPAG>
	(more pages)
	...
.fi
.RE

Example:

.RS
.nf
.ta .65i .95i 3.0i
	... (assume all variables are declared and contain data)
10	CALL SETDV('HPG')
		CALL PLAC(1.0, 0.5, 0.0, 1.0)	!
		CALL AXCODE(0, 3, 1)	!
		CALL LINLOG(0, 1, 1)	! options for 1st graph

		CALL HOWPLT(0, 1, 1)	! option for 1st curve
		CALL CURV(10, X, Y)	! draw the 1st curve

		CALL RIGHT	!--- options for 2nd curve
		CALL HOWPLT(1, 2, 15)	!
		CALL CURV(10, X, Y2)	! draw the 2nd curve
		CALL VG	! draw the 1st graph

		CALL PLAC(0.5, 0.0, 0.5, 1.0)	! option for 2nd graph
		CALL CURV(15, X2, Y3)	! draw the curve on the 2nd graph
		CALL VG	! draw the 2nd graph
	IF(LOOPIN() .EQ. 1) GOTO 10
	... (program continues)
.fi
.RE

produces two graphs on one screen.  The first graph has two curves, one 
plotted against the left y-axis and the other against the right y-axis (see
.I AXCODE and RIGHT).  
The first curve is a solid blue line with no symbols (see
.I HOWPLT); 
the second is a dashed yellow line with circles at data 
points.  Both y-axes are logarithmic (see
.I LINLOG). 
The second graph has a single curve in the default line type.  The axes (x and the left 
hand y) are linear; the right hand y-axis is not used or displayed. 


.SH OPTIONS AFFECTING A CURVE:

.I Symbol, Dash Pattern, and Line Color (HOWPLT)

Unless 
.I HOWPLT 
is called, the first curve is plotted with a circle at each data 
point and with solid white lines connecting each point.  For subsequent curves, 
.I VG 
adds one to the current symbol and dash pattern numbers, and uses 
the symbol and dash pattern indicated by those numbers. When all the 
symbols and dash patterns have been used, the color is changed.  Each new 
graph restarts the cycle.  ON HIGH QUALITY 
HARDCOPY OUTPUT, COLOR IS MAPPED TO LINE WIDTH. 

To set the plotting style of a data set, use:

.RS
CALL HOWPLT(ISYMBL, ISTYLE, ICOLOR)
.RE

where 
.I ISYMBL 
is the symbol code:

.nf
0:	no symbol
1\-23:	various centered symbols shown on the symbol list.
.fi

and 
.I ISTYLE 
is the dash pattern code:

.nf
0:	no line
1:	solid line
2\-11:	dashed lines of various patterns
.fi

and 
.I ICOLOR 
is the color code:

.ta .5iR +1.0i  +1.5iR +1.0i
.nf
	code	color	code	color

	1intense white	9dark gray
	2blue	10dark blue
	3green	11light green
	4cyan	12light cyan
	5red	13pink
	6magenta	14light magenta
	7brown	15yellow
	8white	16intense white
.fi

Note:  your computer may produce fewer colors.

By default symbols (if 
.I ISYMBL
is not equal to zero) will be plotted at every data point.
To change this behavior

.RS
.nf
CALL SETINC(INCSYM)
.fi
.RE

This will result in a symbol being plotted at every 
.I INCSYM
data point.

On laser printers and pen plotters, 
.I ICOLOR 
controls the
width of the line drawn:  larger values of
.I ICOLOR 
produce wider lines.

.I PLOT AGAINST A RIGHT HAND AXIS

To plot data against a right hand axis of a graph, first call
.I AXCODE 
with 
.I IVCODE=3, 
(see "Axis Options", below) and then precede the call to
.I CURV 
with: 

.RS
CALL RIGHT
.RE

.I Legends

A legend is a rectangular box enclosing a list of strings, each 
preceded by a sample of the line whose data are described by the string.  To 
generate a legend entry, before calling
.I CURV
insert 

.RS
.nf
CALL LEGND(STRING)    Example: CALL LEGND('Water')
.fi
.RE

.I STRING 
is the text describing the curve.  
.I LEGND
can be called repeatedly for each curve to produce multi-line legends.  
The legend box will be placed at the center of its 
associated graph.  This can be changed (see "Legend 
Options") and the legend can be moved in the interactively. 
There may not be more than 
fourteen lines in a legend box.

.SH OPTIONS AFFECTING AN ENTIRE GRAPH:

.I (1) Position on Page: 

The position of a graph can be changed by 
using: 

.RS 
.nf
CALL PLAC(TOP, BOTTOM, LEFT, RIGHT)  0.0 <= TOP, BOTTOM, etc., <= 1.0
.fi
.RE

The screen is the unit square with origin at lower left.

.I (2) Axis Options: 

Default: draw lower and upper horizontal 
axes, with numbers along the lower axis, and draw left and right vertical 
axes, with numbers along the left axis.  To set different options, use: 

.RS
.nf
CALL AXCODE(IHCODE, IVCODE, ICOLOR)
.fi
.RE

Where 
.I IHCODE 
is the horizontal axis code number:
   0:  default horizontal axis option as above
   1:  lower and upper horizontal axes, BOTH with numbers.
   2:  lower horizontal axis only (with numbers);

and 
.I IVCODE 
is the vertical axis code number:
   0:  the default vertical axis option as above
   1:  left and right vertical axes, BOTH with numbers,
   2:  left vertical axis only (with numbers),
   3:  DIFFERENT left and right vertical axes.

and 
.I ICOLOR 
is the color of the axes, ticks, and axes numbers (default is 1). 

Set 
.I IVCODE=3 
for graphing dependent variables with two different ranges 
against one independent variable.  See "Plot Against Right Hand Axis", above. 

To suppress numbers on one or more axes, use:

.RS
.nf
CALL NONUM(IX, ILEFTY, IRITY)
.fi
.RE

where
.I IX, ILEFTY, 
and
.I IRITY
are codes for the x, left y, and right y axes: 1 suppresses the
numbers on that axis, 0 leaves them on.
To suppress the drawing of the axes use

.RS
.nf
CALL NOAXES 
.fi
.RE

To suppress drawing of just the x-axis or the y-axis use
.I CALL NOAXEX
or
.I CALL NOAXEY,
respectively.

.I (3) Axis Limits:

Default:  axis limits are "nice" numbers big 
enough to contain all the data.  To override 
this, use: 

.RS
.nf
CALL SETLIM(IAXIS, ITYPE, AMIN, AMAX)
.fi
.RE

where
.I AMIN 
and 
.I AMAX 
are the new limits, 

.I IAXIS
is the axis to change:
   1:  x-axis
   2:  left y-axis
   3:  right y-axis

.I ITYPE
is the kind of change:
   1:  override minimum, but keep "nice" maximum
   2:  override maximum, but keep "nice" minimum
   3:  override both minimum and maximum

. Tic Marks: 

By default, tic marks are placed at "nice" numbers and a number is drawn at each tic mark.  To change this, use:

.RS
.nf
CALL SETTIC(IAXIS, NTICS, STRARR)
.fi
.RE

Where
.I IAXIS
is the axis to change:
   1: x-axis
   2: left y-axis
   3: right y-axis

.I NTICS
is the number of tic marks, and 
.I STRARR(1)...STRARR(NTICS)
is an array of strings to be placed at the tics.  Tics are equally spaced with
text centered at each.
.I NTICS
must be no greater than 14, and the length of
.I STRARR(I)
must be no greater than 20 characters.  The tic marks will be unchanged
even if the graph is zoomed or the axis limits are changed. If
.I NTICS
is negative,
.I +NTICS 
tic marks are placed on the the axis, and the precision of each number placed at a tic mark is specified as a string in
.I STRARR.
For example, the following fragment:

.RS
.nf
CALL SETLIM(1,3,0.0,3.14159)
CALL SETTIC(1,-3,'4')
.fi
.RE

will produce an x-axis with three tics, labeled "0.0000", "1.5708",
"3.1415".  In this case, the tic labels will change if the axis
limits are changed, or the graph is zoomed. 

The length of the tic marks along the four axes can be changed:

.RS
.nf
 CALL TICSIZ(LTCX1, LTCX2, LTCY1, LTCY2)
.fi
.RE

where
.I LTCX1, LTCX2, LTCY1,
and
.LTCY2
can vary from 0 to 100.  The default tic mark length is equivalent to a value
of 10.  Values outside the accepatable range will result in the default
tic mark length.

.I (4) Linear or Logarithmic Axes: 

Default: linear.  To produce a log or 
semilog graph, use: 

.RS
.nf
CALL LINLOG(ILX, ILY1, ILY2)
.fi
.RE

.I ILX, ILY1, 
and 
.I ILY2 
are the code numbers for the horizontal axis, the left 
vertical axis, and the right vertical axis, respectively.  In each case, 0 
means linear and 1 means log. Unless you call 
.I AXCODE 
with 
.I IVCODE=1 
or
.I IVCODE=3
(see "Axis Options", above), 
.I ILY2 
is ignored. 

.I (5) Axis Labels: 

To draw centered axis labels for a graph, use:

.RS
.nf
CALL SIDTEX(TPST, ITPC, BTST, IBTC, LFST, ILFC, RTST, IRTC)
.fi
.RE

where 
.I TPST, BTST, LFST, 
and 
.I RTST 
are strings to be centered along the 
top, bottom, left, and right axes, and 
.I ITPC, IBTC, ILFC, 
and 
.I IRTC 
are 
their respective colors (see color code table above). To omit a string, use 
\' \' (a blank).  Labels created with
.I SIDTEX
will be positioned between the graph's axis numbers and borders set by
.I PLAC
(see "Position on Page", above).  Note that 
.I SIDTEX
can produce only single line labels.  To produce multi-line labels,
use the interactive loop (the easy way, see "Altering and Adding Text"), or
.I GTEX
(harder, but no interaction is needed, see "Adding Text to a Graph",
immediately below).  Labels produced with
.I SIDTEX
can be changed, moved, etc. interactively, like all other text (see,
"Altering and Adding Text", below).

.I To Place Text on a Graph:

.RS
.nf
CALL GTEX(TEXT, X, Y, ANGLE, SIZE, NCOLOR, MODE)
.fi
.RE

Where
.I TEXT
is the text string, e.g., 'Water',
.I X
is the horizontal coordinate of the first letter of
.I TEXT,
.I Y
is the vertical coordinate of the first letter of
.I TEXT,
.I ANGLE
is the number of degrees to rotate counterclockwise,
.I SIZE
is the size of the letters in 
.I TEXT
relative to the base size,
.I NCOLOR
is the color code of 
.I TEXT
(see color table above), and
.I MODE
describes how the text is placed on the graph:
  1:  the x and y coordinates are distances in screen units
  2:  the x any y coordinates are in the same units as the graph's data
  3:  the text is centered horizontally on the graph, and the y coordinate
is a screen distance up from the bottom edge of the graph
  4:  the text is centered vertically on the graph, and the x coordinate
is a screen distance right from the left edge of the graph
  5:  the text is centered horizontally on the graph, and the y coordinate
is a screen distance up from the top edge of the graph
  6:  the text is centered vertically on the graph, and the x coordinate
is a screen distance right from the right edge of the graph

Text characteristics can be changed interactively, but the text will hold its 
position with respect to its graph (according to its mode) if the graph is
moved interactively.  (To lock text onto the screen use
.I HTEX.)
To use
.I GTEX
to make multi-line labels, you'll need to know the height of a line of
text (0.02 screen units times the text size, the 
.I SIZE
parameter in
.I GTEX,
times the scaling factor if you used
.I SCALUP).
Each line of text needs to be offset from the graph edge by the width
of all text between it and the graph, including numbers on the graph.
Also, the left y-axis text is usually rotated to 90.0 degrees and the right
y-axis text is usually rotated to -90.0 degrees.  The following program
will produce a graph with a three line title, a two line y-axis label, and
a one line x-axis label:

.RS
.nf
.ta .65i +.3i
- - -
	SIZE=0.02
c padding ten characters wide to avoid axis numbers
	PAD=0.2
c create title
	CALL GTEX('Some Data', 0.0, 2*SIZE, 0.0, 1.0, 1, 5)
	CALL GTEX('By', 0.0, SIZE, 0.0, 1.0, 1, 5)
	CALL GTEX('Hopfrog J. Mega-User', 0.0, 0.0, 0.0, 1.0, 1, 5)
c y-axis label
	CALL GTEX('Time', -HEIGHT-PAD, 0.0, 90.0, 1.0, 1, 4)
	CALL GTEX('(Years)', -PAD, 0.0, 90.0, 1.0, 1, 4)
c x-axis label
	CALL SIDTEX(\' \',1,'Money ($)',1,\' \',1,\' \',1)
---
.fi
.RE

There is a limit of 50 lines of text on a page, including text added by
.I GTEX, HTEX,
and
.I SIDTEX.

For more information about text, see "Text in VG", below.

.I (6) Legend Placement: 

Default: legend is centered on its graph.  
To change the location for a legend, use: 

.RS
.nf
CALL LEGPOS(XLEG, YLEG)
.fi
.RE

where 
.I (XLEG, YLEG) 
are the screen coordinates of the center of the legend. (Screen is 
unit square.)  Thus, 
.I CALL LEGPOS(0.5, 0.66) 
would center a legend halfway 
across the screen, and two-thirds of the way up.  Calling 
.I LEGPOS 
does not 
prevent a legend from being moved interactively.  A legend is surrounded
by a box or frame.  To make the frame invisible use
.I CALL NOLBOX
anytime before the call to
.I VG.

.I (7) Grid Points and Zero Axes: 

Defaults: no grid points and no zero axes (lines x=0 and y=0).  To 
change use: 

.RS
.nf
CALL SETGRD(IFID, IZERO)
.fi
.RE

where 
.RS
.nf
IFID = 0 no grid points,
IFID = 1 draw grid points and

IZERO = 0  no zero axes
IZERO = 1  draw any zero axis that is on the graph
IZERO = 2  draw zero axes only if both are on the graph
.fi
.RE

.I Creating a Blank Box:

To place an empty rectangle on a graph use:

.RS
.nf
CALL BBOX(ATOP, ABOT, ALEFT, ARIGHT, INGRAF)
.fi
.RE

where
.I ATOP, ABOT, ALEFT,
and
.I ARIGHT
are the sides of the box, and
.I INGRAF=0
indicates that the side coordinates are in screen coordinates,
.I INGRAF=1
indicates that the side coordinates are in the graph's coordinates.
The frame can be turned off by using
.I NOLBOX,
above.  A graph cannot have both a legend and an empty box.

.SH OPTIONS AFFECTING AN ENTIRE PAGE

.I To place text on the page, use:

.RS
.nf
CALL HTEX(TEXT, X, Y, ANGLE, SIZE, NCOLOR)
.fi
.RE

where 
.RS
.I TEXT 
is the text string, e.g. 'water'

.I X 
is the horizontal coordinate of the first letter of 
.I TEXT
(negative value centers - 0.0 is the left edge, 1.0 is the right edge),

.I Y 
is the vertical coordinate of the first letter of 
.I TEXT
(negative value centers 0.0 is the bottom, 1.0 is the top edge),
 
.I ANGLE 
is the number of degrees to rotate counterclockwise,

.I SIZE 
is the size of the letters in 
.I TEXT 
relative to the base size, and

.I NCOLOR 
is the color code of 
.I TEXT 
(see color table above)
It is not possible to have more than 50 lines of text on any one screen.
This limit includes text added by 
.I GTEX, HTEX,
and
.I SIDTEX.
Text can also be manipulated interactively.  Also see "Text in VG", below.
.RE

.I Text and Symbol Size

The base size of all text and centered graphing symbols to be drawn is 0.35 
centimeters tall on a printed page.  To change this base size, 

.RS
.nf
CALL SCALUP(FACTOR)
.fi
.RE

where 
.I FACTOR 
is the desired multiple (or fraction) of the base height. Note 
that the 
.I SIZE 
parameter in 
.I HTEX 
(immediately above) also affects the height 
of text, so that the fragment: 

.RS
.nf
CALL SCALUP(2.0)
CALL HTEX('A LINE', 0.1, 0.3, 0.0, 1.0, 1)
CALL HTEX('ANOTHER LINE', 0.1, 0.5, 0.0, 0.75, 1)
...
.RE
.fi

Will draw "A LINE" at twice normal size and "ANOTHER LINE" at one and a half 
times normal size. 

.I Setting the Output Device: 

Default: PostScript.  To produce a file for another
type printer, use: 

.RS
.nf
CALL SETDV(DEVNAM)    Example: CALL SETDV('QMS')
.fi
.RE

where 
.I DEVNAM 
is a three letter code for the printer format:

.RS
.nf
tek:  Tektronix
hpg:  HPGL-Plotter
pos:  PostScript
qms:  QMS-Lasergrafix
.fi
.RE

This remains in effect until changed by another call to 
.I SETDV 
or changed interactively. 

.SH FEATURES OF THE INTERACTIVE LOOP:

When the program pauses after displaying the current page, 
it is in the normal interactive mode.  Typing 
.I '<enter>'
causes the program to exit the interactive mode (i.e. when
you press 
.I '<enter>' LOOPIN
returns 0 and reults in 
an exit from the interactive loop).  This section
describes the interactive commands that can be used.

.I Zooming

If you type 
.I 'z',  
four "zoom corners" will appear in one of the graphs on 
the screen.  

Use the cursor control keys to translate the zoom box. (On PCs these are 
the arrow keys on the right part of your keyboard. On other systems use 
the letter keys 
.I I, J, K, M 
to move up, left, right and down. To move the 
zoom box in finer increments, type 
.I 'f'; 
to go back to coarse movement, 
type 
.I 'c' 
again. 

This translates the zoom box; i.e., "whole-moving" mode. Type 
.I 's', 
to enter "side-moving" mode, and subsequent arrow keystrokes move ONE SIDE 
of the zoom box.  Typing an arrow key causes one side of the box to move 
outward To move a side INWARD, type a SHIFTED arrow key:  e.g., shifted 
up arrow moves the top edge down. To get back to "whole-moving" mode, 
type 
.I 'w'.  

Once the zoom box has been satisfactorily specified, type
.I 'z' 
again, to actually accomplish the zoom.


Press the 
.I Esc 
key to remove the zoom box without zooming and return to the normal
interactive mode.

There is always a "current" 
graph, in which zoom corners will appear if you hit 
.I 'z'; 
to change this 
use the space bar.  Each time the space bar is hit, a star will flash in 
the center of a different graph -- the one that is now current.  Hit the 
space bar until the star indicates the desired graph, 
then hit 
.I 'z' 
to 
produce zoom corners. If the zoom corners are in the wrong graph, don't 
press the space bar; press
.I Esc, 
THEN space bar until the right 
graph is selected.  Backspace goes back one graph.  Then press
.I 'z' 
and proceed. 

Type 
.I 'r', 
to "restore" or "zoom out".  You can "zoom out" several times. 

Note that zooming will change the mode of all text associated with
the graph in mode 2 ("sticking to a point") to mode 1 ("staying
a distance from the lower left corner").  See "Adding Text to a
Graph" (above) and "Text in VG" (below).

.I Rearranging Graphs

Typing 
.I 'a' 
(for "arrange") 
causes four corners to momentarily flash around the "current" graph
and places 
.I VG
in arrange mode.
The cursor keys, shift keys, 
.I 'f', 'c', 'w', 
and 
.I 's' 
work as in "zoom" mode (see above).  The current graph will be 
erased, its new position and shape being indicated only by the corners.  
To draw the graph in its new position, type 
.I 'd'. 
This shifts back into 
"normal" mode.  To move several graphs, then redraw them all at a 
stroke:  type 
.I 'a', 
use the spacebar until corners flash around a graph 
you want to move, move it, use the space bar to select
a different graph, etc., then hit 
.I 'd' 
and all the graphs you moved will be redrawn. 

If the screen becomes cluttered hit 
.I 'x' 
which redraws the entire screen.

Type
.I Esc
to leave the arrange mode without changing any graphs.


.I Moving Legends

Legend boxes can be moved.  To enter legend moving mode, type 
.I 'l'.  
Corners 
will briefly flash around the "current" legend.  Select the legend using the 
space bar and/or the backspace key and move the legend around as 
in "zoom" mode. The size of the legend box can't be changed.  Type 
.I 'd' 
to 
draw the currently selected legend, 
.I 'x' 
to clean up the screen, or
.I 'v'
to toggle the current legend between visible and invisible. 

Type 
.I Esc
to leave the legend mode without changing any legends.

.I Editing a Graph's Axes:

Type
.I 'e' 
(edit) to change the min/max values on a graph's axes, to switch
between linear and logarithmic axes, or to number/unnumber axes.  Move the
pointer ">" to select items to change (does not work too well with Tektronix
emulation), and type
.I 'c'
to change them.  Exit edit mode with
.I Esc
which ignores the changes, or with
.I 'u'
(update) to redraw the screen incorporating the changes.

.I Altering and Adding Text

Text strings from 
.I HTEX, GTEX,
or
.I SIDTEX,
can be manipulated interactively.  New text can be added, even if none of
these routines were called.  Type
.I 't'
to enter the text mode; 
a star flashes at 
the first letter of the "current" text strings.  Use the 
spacebar/backspace to select a string.  Then translate 
it using the arrow keys, or rotate it right (clockwise) with 
.I 'r' 
or left 
(counterclockwise) with  
.I 'l'.  
The size of the characters can also be 
changed:  they can be made larger by typing 
.I '+' 
and smaller by typing 
.I '-'.
Type
.I '>'
to increase the text's color code and
.I '<'
to decrease it (see the table of color codes above).  
Typing
.I '!'
will delete the current text line.  To edit the current line, type
.I 'e';
you will be prompted for the new contents.

The fineness of translation, rotation and resizing of text can be changed.
To go to "fine" movement, hit 
.I 'f'; 
for "ultrafine", hit 
.I 'u'; 
to return to 
"coarse", hit 
.I 'c'.  

To change the current string's owner to the current graph, hit
.I 'o'.
The current graph is indicated by corners around its frame.  When the screen
is the current graph, the corners appear in the screen's corners.  To change
the current graph, type
.I ']'
for the next graph, or
.I '['
for the previous one.  (For a discussion of text ownership, see "Text
in VG", below.)

To change a current string's mode to "keep a distance" mode. type
.I 'd'.
To change it to "stick to a point" mode, type
.I 'p'.
To center the current string horizontally, and change its mode to 
horizontal centering, type
.I 'h'.
To center the center the current string vertically, and change its mode
to vertical centering, type
.I 'v'.
To change a string's mode between normal left vertical centering and right
vertical centering or normal bottom horizontal centering and top horizontal
centering, type
.I '@'.
(For a discussion of positioning modes, see "Text in VG", below.)

To display the current line's color code, owner number, and positioning mode, type
.I 's'
(status).  Type
.I 's'
again to stop displaying the status.

To make the current line into an axis label which will act like one entered
with
.I SIDTEX
(see "Axis Labels", above), type
.I 'a'.
The current line will then be "owned" by the current graph.  The label it
becomes depends on its positioning mode: a top centered line becomes a title,
and so forth.  If the current line is not centered, it will not become a label.

To add new text, hit 
.I 'n'.  
A prompt will appear, asking for the contents of 
the new line.  The new line will have the same size and rotation as the 
current one, and be positioned to line up as the next line "under" it, even 
if the current line is at an angle.  The new line will have the same
positioning mode as the current one, unless the current one is centered.  In
that case, the new line will have "keep a distance" mode.  The new line
will be owned by the current graph, NOT the current line's owner.  
The new line becomes
the current line, so that blocks of text may be added easily.  Each page 
(screen) cannot have more than fifty lines of text.  

Hit 
.I 'x' 
to clean up the screen and return to normal mode. Type
.I Esc
to leave text mode without redrawing the screen. 

.I Printing

.I VG 
can produce an output file for a laser printer or pen plotter.
The default format for high quality printing is PostScript (unless altered 
with 
.I SETDV.  
See "Setting the Output Device", above).  This format can be 
changed in the interactive loop by typing 
.I 'h' 
which then prompts for a device 
name; give the code name  mentioned with 
.I SETDV.  
To print the screen, type 
.I 'p' 
and provide a file name.  This file can be sent to an appropriate 
printer.  

.I The Cursor

.I VG
has a graphics cursor for finding the position of items on graphs and
extracting those values into your program.  Type
.I 's'
to show the cursor.  Then type
.I 'w'
to display the cursor position in coordinates of the current graph.
Typing
.I '*'
passes the cursor's location by calling
.I VGCURS(X, Y).
To capture this data, write
.I SUBROUTINE VGCURS(X, Y)
and save local values of
.I X
and
.I Y.
For example, the following program fragment will log up to six cursor
positions and then take their average:

.RS
.nf
.ta .65i +.3i
	REAL SAVEX(6),SAVEY(6),SUMX,SUMY,AVGX,AVGY
	COMMON/CDATA/SAVEX,SAVEY,I
	...
	I=0
10	CALL PLAC(1.0, 0.5, 0.0. 0.5)
	...(OTHER VG CALLS)...
	IF(LOOPIN().EQ.1)THEN 10
C	TAKE AVERAGE OF VALUES LOGGED BY CURSOR
	SUMX=0.0
	SUMY=0.0
	IF(I.GT.0)THEN
		DO 20 J=1,I
			SUMX=SUMX+SAVEX(J) 
20			SUMY=SUMY+SAVEY(J)
		AVGX=SUMX/I
		AVGY=SUMY/I
	ENDIF
	...
	SUBROUTINE VGCURS(X, Y)
	REAL SAVEX(6),SAVEY(6)
	COMMON/CDATA/SAVEX,SAVEY,I
	I=I+1
	IF(I.LE.6)THEN
		SAVEX(I)=X
		SAVEY(I)=Y
	ENDIF
	RETURN
	END
.fi
.RE

If
.I SUBROUTINE VGCURS(X, Y)
does not exist, typing
.I '*'
will do nothing.  To toggle cursor off, type
.I 's' 
again.

.SH LEAVING THE INTERACTIVE LOOP

Leave the interactive loop by typing 
.I <enter>.
The calling program continues after resetting the screen to text mode. 
A second keystroke to end the loop can be added with 
.I SETXIT 
(immediately below).   A sequence of plots can be converted to high quality
print files without interaction, by typing 
.I 'g'
(for 'go') and entering a file name such as PLOTS.  If the high quality
syntax is Postscript, the files will be  called PLOTS01.POS, PLOTS02.POS,
etc.  Also see 
.I BATCH LOOP
(below).

If you have set automatic printing (see "Printing on Loop  Exit"), and
want to leave without creating a file for the current screen, type
.I 'o',
for 'override'.  Overriding for one screen will not turn off 
automatic printing for subsequent screens.

.SH ADDING A COMMENT LINE TO THE LOOP

To provide a comment line which will not appear when the screen is printed
(to provide instructions to the user, for instance) use:

.RS
.nf
CALL COMMEN(STRING)    Example: CALL COMMEN('<Enter> to Exit')
.fi
.RE

The comment line will be hidden when you enter any of the modes in the
interactive loop, and will remain until changed.  To remove the comment
line, replace
.I STRING
with a blank:

.RS
.nf
CALL COMMEN(' ')
.fi
.RE

The comment line is left justified.

.SH ADDING A SECOND EXIT CHARACTER TO THE LOOP: (acts like '<enter>")

In addition to the normal loop exit character, the enter key, a second
character can be established.  The second exit character is specified
by:

.RS
.nf
CALL SETXIT(ICHAR)    Example: CALL SETXIT(27)
.fi
.RE

where
.I ICHAR
is the ASCII code for the character.  The code of a common exit character,
escape, is 27.  The
.I SETXIT
remains in effect until changed.  Calling
.I SETXIT(0)
forces
.I VG
to exit immediately after flashing a plot, without any user input.

.SH PRINTING ON LOOP EXIT

To have
.I VG
automatically create a high quality print file whenever you exit the interactive loop, place

.RS
.nf
CALL XITPRN(.TRUE.)
.fi
.RE

before the call to
.I LOOPIN.
When you exit any screen after
.I CALL XITPRN, VG
will create the print file VGnn.dev (where nn is the page number of that
page, and dev is the three letter code for the printing syntax).  To change
"VG" to another name see
.I SETFIL
(below).  Automatic printing will remain in effect until turned off with:

.RS
.nf
CALL XITPRN(.FALSE.)
.fi
.RE

Automatic printing can be overridden from the interactive loop to allow
exit without printing (override with 'o', see "Leaving the Interactive Loop", above).

.SH THE BATCH LOOP

The batch loop is used for creating high quality output files without
any interaction.  Replace "LOOPIN" with "LOOPBT".

The default output file is VGnn.dev, where nn is the page number of that
output page, and dev is the three letter code for the syntax.  To change
"VG" to some other name.

.RS
.nf
CALL SETFIL(NAME)    Example: CALL SETFIL('RESULT')
.fi
.RE

where
.I NAME
is the base file name of up to six characters.  
.I VG
appends the page number and the device type to the name.
No more than 99 pages can be generated in batch loops.  A main
program CAN contain calls using both the interactive and batch loops.

.SH SMOOTH INTERPOLATION:

Normally,
.I VG
plots an (optional) symbol at each data point, connecting these
symbols with (optional) straight line segments.  To produce a smooth
curve through a data set replace the call to 
.I CURV
with a call to
.I SCURV.

The interpolation scheme used was developed by
Dyn, Gregory, and Levin and has 
been referred to as
a 4-point subdivision scheme similar to approximations using
Bezier functions.  For 
.I N
less than 3 or
.I N
greater than 847 there will be no interpolation.


.SH CONTOUR PLOTS:

In order to create a contour plot, replace a call to 
.I CURV
with:

.RS
.nf
CALL CONTOR(N, M, X, Y, Z)
.fi
.RE

where:
  N is the number of columns of points,
  M is the number of rows of points,
  X is a vector containing the x-values of the columns,
  Y is a vector containing the y-values of the rows,
  and Z is an N by M array containing the z-values at each point.

There may be only one contour plot per graph, and a contour plot may not
have any other curves (from
.I CURV, SCURV, ERRBAR,
or
.I DCURV)
on it.  Having a contour plot does not affect the options available to
other graphs.  To change options on the z-axis 
.I (LINLOG
or
.I SETLIM,
for example) refer to it as the right hand y-axis.  For instance,

.RS
.nf
CALL SETLIM(3, 1, 5.0, 0.0)
CALL CONTOR(N, M, X, Y, Z)
CALL VG
.fi
.RE

sets the contour plot's z-axis minimum to 5.0.  
.I CONTOR
adds a legend to the contour plot describing the min, max, and contours
of the plot.  More legend lines can be added to this legend.  To suppress
the
.I CONTOR
legend lines, turn off numbering on the z-axis (see "Axis Options" and
"Editing a Graph's Axes", above).

.SH ERROR BARS:

To plot a curve with error bars replace a call to
.I CURV
with:

.RS
.nf
CALL ERRBAR(N, X, Y, XERRS, YERRS, IX, IY)
.fi
.RE

where:
  N, X, Y have the same meaning as in
.I CURV,
  XERRS is a vector of errors in the x-direction,
  YERRS is a vector of errors in the y-direction, and
  IX=1 draw error bars in X,
  IX=0 no error bars in X,

Similarly for IY.

.SH HISTOGRAMS

To plot a histogram, replace a call to
.I CURV
with:

.RS
.nf
CALL HIST(N, X, Y, BARWID)
.fi
.RE

where
.I N, X, Y
have the same meaning as in
.I CURV,
and 
.I BARWID
is the width of the bars drawn.

.SH DOUBLE PRECISION DATA

To plot a curve with double precision data, replace
.I CURV
with
.I DCURV.
The data is internally converted to REAL, so that
.I DCURV
is bounded by the limits of REALs.

.SH HOW VG HANDLES ERRORS:

.I VG, 
if possible, ignores incorrect data.  For example if 
.I HOWPLT 
is called as

.RS
.nf
CALL HOWPLT(1, 23, 4)
.fi
.RE

the default line type (color, style, and symbol) is used.  

.SH TEXT IN VG

There are several ways to create lines of text in
.I VG: SIDTEX
creates one-line labels for graphs,
.I GTEX
attaches text to graphs,
.I HTEX
makes text elsewhere, and text can be added in the interactive loop.
To support functions such as the centering of axis labels and the
positioning of text, information about each line of text is needed
beyond its location, size, and color.  These pieces of information are
the line's owning graph and its positioning mode.

All text is "owned" by a graph.  When the line's owner is moved or
changed, the text responds: if a graph is moved, its title becomes
centered over its new location.  Owner numbers are assigned to graphs
in the order the graphs are created in your program.  To avoid having
to make a special case, the screen is considered to be a graph, and is
given the owner number 0.  When text is made with
.I HTEX,
its owner is the screen.  When text is made with
.I GTEX
or
.I SIDTEX,
its owner is the graph that made it.

A text line's positioning mode describes how the line reacts to
changes in its owner.  There are six positioning modes.  (1) Keep the
line a given distance from the lower left corner of the owner,
regardless of how the owner's size or axis limits change.  (2) Keep
the line at a given coordinate on the graph, even when the graph is
resized or given new axis limits.  When the owner is the screen, there
is no difference between (1) and (2).  The last four modes deal with
centering: (3) centers horizontally with respect to the owner's edges,
staying a constant distance up from the owner's bottom edge, (4)
centering vertically, offset from the left edge.  (5) centers
horizontally, like (3), but the offset is from the top edge.
Likewise, (6) centers vertically, similar to (4), but the offset is
from the right edge.
.I SIDTEX
sets positioning modes to keep the labels correctly centered;
.I HTEX
sets the positioning mode implied by the input.
.I GTEX
takes the desired mode as a parameter.

Both owner and positioning mode can be changed interactively.  Only
centering results in a visible change in the text, but the effects
often will not be seen until graphs are changed or moved.  A status
line is provided, giving the text's owner number and mode, so one can
tell how the text will act.

.I Determining Version Number of VG 

To determine the version of
.I VG, use

.RS
.nf
CALL VGVER
.fi
.RE

.I GREEK, SUPERSCRIPT, AND SUBSCRIPT CHARACTERS

To draw a Greek character, precede the letter by `|'. Thus `|a' will draw an 
alpha.  To subscript or superscript a 
character, precede it with  `_' or `^'.  Thus `H_2O' is the formula for 
water. Use `^^' to get super-superscript, like `e^x^^2'.  To generate a
Greek subscript, such as alpha, use `_|a'.  To generate `|', `_', or
`^' precede it with `|' as in `||sin(x)||'. 

.I Special characters

Some extra characters of occasional use (integral, square root, arrow,
etc.) are also available.  To get them first lookup their THREE digit
code in the character set table (for example the code for a right arrow
is 169).  Then in any call to
.I HTEX, GTEX,
or
.I SIDTEX,
or interactively, enter the code as a string preceded by a
.I \\\,
for example '\\202'.  To get a backslash, use '\220'.

.SH ALPHABETICAL SUMMARY OF VG CALLS:

.nf
Call	Summary
-------------------------------------------------------------------------

AXCODE	set axis options
BBOX	create a blank box
CURV	draw curve on a graph
COMMEN	place a non-printing comment line
CONTOR	draw a contour plot
DCURV	draw curve using double precision
ERRBAR	draw curve with error bars
GTEX	add text to a graph
HIST	draw a histogram
HOWPLT	set line and symbol types for curve
HTEX	draw line of text of any character size
LEGND	produce legend entry for curve        
LEGPOS	set position for legend              
LINLOG	set linear or logarithmic axes for graph
LOOPIN	call interactive loop                  
LOOPBT	call batch loop                       
NEWPAG	start new screen (page)             
NOAXE{S,X,Y}	suppress drawing of graph's axes   
NOLBOX	suppress drawing box around legend
NONUM	suppress drawing of graph's axis numbers
PLAC	set graph's location                   
RIGHT	plot next curve against right y-axis  
SCALUP	change size of characters and symbols
SCURV	draw smoothed curve                 
SETDV	set high quality syntax            
SETFIL	set batch loop high quality file name 
SETGRD	set grid options
SETINC	change "distance" between plot symbols
SETLIM	set axis limits
SETTIC	set number of tic marks and tic text
SETXIT	add another interactive loop exit key
SIDTEX	draw axis labels                    
TICSIZ  modify length of tic marks
VG	draw all features of graph, excluding curves
VGCURS	get cursor data
VGVER   print VG version number
XITPRN	set printing on interactive loop exit
.fi

.SH SUMMARY OF VG CALL PARAMETERS:

.nf
Call with Parameters
-------------------------------------------------------------------------

AXCODE(IHCODE, IVCODE, ICOLOR)
BBOX(TOP, BOTTOM, ALEFT, RIGHT, INGRAF)
CURV(N, X, Y)
COMMEN(STRING)
CONTOR(N, M, X, Y, Z)
DCURV(N, X, Y)
ERRBAR(N, X, Y, XERR, YERR, IX, IY)
GTEX(TEXT, X, Y, ANGLE, SIZE, NCOLOR, MODE)
HIST(N, X, Y, BARWID)
HOWPLT(ISYMBL, ISTYLE, ICOLOR)
HTEX(TEXT, X, Y, ANGLE, SIZE, NCOLOR)
LEGND(STRING)
LEGPOS(XLEG, YLEG)
LINLOG(ILX, ILY1, ILY2)
NEWPAG
NOAXE{S,X,Y}
NOLBOX
NONUM(IX, ILEFTY, IRITY)
PLAC(TOP, BOTTOM, LEFT, RIGHT)              
RIGHT
SCALUP(FACTOR)
SCURV(N, X, Y)
SETDV(DEVNAM)
SETFIL(FILNAM)
SETGRD(IFID, IZERO)
SETINC(INCSYM)
SETLIM(IAXIS, ITYPE, AMIN, AMAX)
SETTIC(IAXIS, NTICS, STRARR)
SETXIT(ICHAR)
SIDTEX(TOPSTR, ITOPC, BOTSTR, IBOTC, LEFSTR, ILEFC, RITSTR, IRITC)
TICSIZ(LTCX1, LTCX2, LTCY1, LTCY2)
VG
VGCURS(X, Y)
VGVER
XITPRN(PRINT)
.fi

.SH SUMMARY OF INTERACTIVE LOOP COMMANDS

.ta 1.2i
.nf
Command	Effect
-------------------------------------------------------------------
<space>	move to next graph
<backspace>	move to previous graph
<enter>	leave interactive loop, setting screen to text mode
a	enter graph arrange mode  (see below for options)
c	switch to coarse cursor movement
e	enter graph editing mode (see below for options)
f	switch to fine cursor movement
g	leave interactive loop, screen to text mode, flash next plots
h	set high quality output device (pos, qms, hpg, tek)
l	enter legend moving mode  (see below for options)
o	leave interactive loop, overriding automatic printing
p	create high quality graphics output file
r	restore current graph by unzooming one level
s	show cursor
t	enter text mode  (see below for options)
w	show where cursor is
x	redraw (cleanup) screen
z	enter zoom mode (see below for options)
*	catch cursor's position

Arrange mode commands:
<escape>	exit arrange mode, making no changes
<space>	move to next graph
<backspace>	move to previous graph
<cursor keys>	adjust position of graph [Also use IJKM keys]
<shift>	modifies effect of cursor keys in side mode
c	switch to coarse movement
d	exit arrange mode, drawing the current positions
f	switch to fine movement
s	enter graph side moving mode
w	enter whole graph moving mode

Edit mode commands:
<escape>	exit edit mode, making no changes
<cursor keys>	move pointer [Use IJKM keys on nonPCs]
c	change current item
u	update graph to reflect change and exit

Legend mode commands:
<space>	move to next legend box
<backspace>	move to previous legend box
<cursor keys>	adjust position of legend box [Also use IJKM keys]
c	switch to coarse movement
d	draw the currently selected legend, leave legend mode
f	switch to fine movement
v	toggle legend between visible and invisible

Text mode commands:
<space>	move to next text line
<backspace>	move to previous text line
<cursor keys>	move current text line [Also use IJKM keys]
a	make current line into an axis label
c	switch to coarse movement
d	change current line's mode to "keep distance"
e	edit current line of text (e <escape> <enter> deletes line)
f	switch to fine movement
h	center current text line horizontally
l	rotate current text line left (counterclockwise)
n	add a new text line
o	change current text line's owner to current graph
p	change current line's mode to "stick to point"
r	rotate current text line right (clockwise)
s	show color, owner, and mode of current text line
u	switch to ultrafine movement
v	center current text line vertically
x	exit text mode, redrawing screen
+	increase size of current text line
-	decrease size of current text line
!	delete current text line
<	decrease current text line's color code
>	increase current text line's color code
[	move to previous graph
]	move to next graph
@	change current line's centering mode

Zoom mode commands:
<escape>	exit zoom mode, making no changes
<cursor keys>	adjust position of zoom box [Also use IJKM keys]
<shift>	modifies effect of cursor keys in side mode
c	switch to coarse movement
f	switch to fine movement
r	restore current graph by unzooming one level
s	enter zoom box side moving mode
w	enter whole zoom box moving mode
z	zoom, leaving zoom mode
.fi

.SH FILES
/usr/local/lib/libvg.a
/usr/local/lib/libvgbat.a
/usr/local/lib/libvgsun.a
/usr/local/lib/libvgtek.a

.SH BUGS
Interactive sessions using the Tektronix emulation
can get messy.  The user may need to redraw the
screen often.  

Report bugs to kahaner@vax.cam.nist.gov

.SH AUTHORS

W. Anderson, D. Argentar, G. Candela, D. Kahaner, U. Kattner, M. Reed

.nf
National Institute of Standards and Technology  (Formerly NBS)
Room A151 Technology Building, Gaithersburg MD 20899 (USA)
Contact: D. Kahaner  (301) 975-3808, -3823, -3805
.fi
